@@ -2,6 +2,7 @@ import os
 import subprocess
 import paramiko
 from log import log
+from datetime import datetime
 from func_timeout import func_set_timeout
 from func_timeout.exceptions import FunctionTimedOut
 from paramiko.ssh_exception import SSHException
@@ -48,8 +49,7 @@ class SSHClient(object):
         except:
             pass
 
-    @func_set_timeout(int(os.environ.get("SSH_COMMAND_TIMEOUT", 60)))
-    def _exec(self, cmd, promt_response):
+    def _exec(self, cmd, promt_response,timeout=60):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
             if promt_response:
@@ -57,7 +57,14 @@ class SSHClient(object):
                 channel.get_pty()  # 获取虚拟终端
                 channel.exec_command(cmd)
                 output = ""
+                begin=datetime.now()
+                stderr = ""
                 while not channel.closed or channel.recv_ready() or channel.recv_stderr_ready():
+                    end = datetime.now()
+                    if (end-begin).total_seconds()>timeout:
+                        return_code=1
+                        output=""
+                        stderr=f"timeout to run cmd.{cmd}"
                     if channel.recv_ready():
                         output = channel.recv(1024).decode('utf-8', 'ignore')
                         print(output, end='')
@@ -70,12 +77,12 @@ class SSHClient(object):
                                 # 发送相应的回答
                                 channel.send(response)
                     if channel.recv_stderr_ready():
-                        print(channel.recv_stderr(2024).decode('utf-8', 'ignore'), end='')
+                        stderr=channel.recv_stderr(2024).decode('utf-8', 'ignore')
 
                 return_code = channel.recv_exit_status()
-                return ExecResult(return_code, output, "")
+                return ExecResult(return_code, output, stderr)
             else:
-                stdin, stdout, stderr = self.__ssh.exec_command(cmd)
+                stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
@@ -90,7 +97,7 @@ class SSHClient(object):
             os.environ["SSH_COMMAND_TIMEOUT"] = str(timeout)
             if not self.is_active():
                 raise RuntimeError("ssh transport is not active.")
-            return self._exec(cmd,promt_response)
+            return self._exec(cmd,promt_response,timeout)
         except FunctionTimedOut as e1:
             log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
             return ExecResult(1, "", str(e1))
